##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling data object in SAP LeanIX.
  * Data objects in SAP LeanIX aim to capture information that is relevant for business and the application layer. SAP LeanIX is not a master data management (MDM) or data lineage tool to create in-depth data architectures. You can leverage tools like Collibra, which is integrated with SAP LeanIX.
